==> 0.2.18.tar.gz: lib/widgets/grey_input_container.dart <==
import 'package:feed_plugin/utilities/constants.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

final appGreyBackgroundColor = Color(0xFF44444F);

class GreyInputContainer extends StatelessWidget {
  const GreyInputContainer({
    Key key,
    @required this.usernameController,
    this.suffixIcon,
    this.prefix,
    this.labelText,
    this.validatorText,
    this.obscureText,
    this.keyboardType,
    this.enabled = true,
    this.inputFormatters,
    this.validator,
  }) : super(key: key);

  final TextEditingController usernameController;
  final Widget suffixIcon;
  final Text prefix;
  final String labelText;
  final String validatorText;
  final bool obscureText;
  final TextInputType keyboardType;
  final bool enabled;
  final List<TextInputFormatter> inputFormatters;
  final FormFieldValidator<String> validator;

  @override
  Widget build(BuildContext context) {
    return TextSelectionTheme(
      data: TextSelectionThemeData(cursorColor: Colors.grey),
      child: Container(
        padding: EdgeInsets.only(left: 16),
        height: 52,
        decoration: BoxDecoration(
          color: appGreyBackgroundColor,
          borderRadius: BorderRadius.circular(4),
        ),
        child: TextFormField(
          enabled: enabled,
          obscureText: obscureText,
          keyboardType: keyboardType,
          style: greyInputTextStyle,
          controller: usernameController,
          validator: validator,
          autovalidateMode: AutovalidateMode.onUserInteraction,
          inputFormatters: inputFormatters != null ? inputFormatters : [],
          textAlignVertical: TextAlignVertical.center,
          decoration: InputDecoration(
            suffixIcon: suffixIcon != null ? suffixIcon : null,
            prefix: prefix != null ? prefix : null,
            border: InputBorder.none,
            focusedBorder: InputBorder.none,
            enabledBorder: InputBorder.none,
            errorBorder: InputBorder.none,
            disabledBorder: InputBorder.none,
            isDense: true,
            labelText: labelText,
            labelStyle: greyInputLabelStyle,
          ),
        ),
      ),
    );
  }
}

==> 0.3.23+1.tar.gz: lib/widgets/grey_input_container.dart <==
import 'package:feed_plugin/utilities/colors.dart';
import 'package:feed_plugin/utilities/constants.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';


class GreyInputContainer extends StatelessWidget {
  const GreyInputContainer({
    Key? key,
    required this.usernameController,
    this.suffixIcon,
    this.prefix,
    this.labelText,
    this.validatorText,
    this.obscureText,
    this.keyboardType,
    this.enabled = true,
    this.inputFormatters,
    this.validator,
  }) : super(key: key);

  final TextEditingController usernameController;
  final Widget? suffixIcon;
  final Text? prefix;
  final String? labelText;
  final String? validatorText;
  final bool? obscureText;
  final TextInputType? keyboardType;
  final bool enabled;
  final List<TextInputFormatter>? inputFormatters;
  final FormFieldValidator<String>? validator;

  @override
  Widget build(BuildContext context) {
    return TextSelectionTheme(
      data: TextSelectionThemeData(cursorColor: Colors.grey),
      child: Container(
        padding: EdgeInsets.only(left: 16),
        height: 52,
        decoration: BoxDecoration(
          color: appGreyBackgroundColor,
          borderRadius: BorderRadius.circular(4),
        ),
        child: TextFormField(
          enabled: enabled,
          obscureText: obscureText!,
          keyboardType: keyboardType,
          style: greyInputTextStyle,
          controller: usernameController,
          validator: validator,
          autovalidateMode: AutovalidateMode.onUserInteraction,
          inputFormatters: inputFormatters != null ? inputFormatters : [],
          textAlignVertical: TextAlignVertical.center,
          decoration: InputDecoration(
            suffixIcon: suffixIcon != null ? suffixIcon : null,
            prefix: prefix != null ? prefix : null,
            border: InputBorder.none,
            focusedBorder: InputBorder.none,
            enabledBorder: InputBorder.none,
            errorBorder: InputBorder.none,
            disabledBorder: InputBorder.none,
            isDense: true,
            labelText: labelText,
            labelStyle: greyInputLabelStyle,
          ),
        ),
      ),
    );
  }
}
